**Example 1: DeleteMesh**



Input: 

```
tccli tcm DeleteMesh --cli-unfold-argument  \
    --MeshId xx \
    --NeedDeleteCLS false \
    --NeedDeleteTMP false \
    --NeedDeleteAPM false \
    --NeedDeleteGrafana false
```

Output: 
```
{
    "Response": {
        "RequestId": "eac6b301-a322-493a-8e36-83b295459397"
    }
}
```

